@@ -2,7 +2,7 @@ from django.conf import settings as django_settings
 
 BASIC_NOTIFICATIONS = {
     'DEFAULT': {
-        'persistant': True,  # stays until dismissed
+        'persistent': True,  # stays until dismissed
         'send_as_email': False,  # send as email
         'headline_template': '{{headline}}',  # Django template for headline
         'body_template': '{{body}}',  # Django template for body
